@@ -1,9 +1,16 @@
 import os
 from .core.utils import module as module_utils
 from .core.utils import library_parameters
-from .core.utils.library_parameters import library_parameters as par, temp_library_parameters as temp_par
+from .core.fileio import loadfile
+par=library_parameters.library_parameters
+temp_par=library_parameters.temp_library_parameters
 
-from .core import *
+from .core.dataproc.__export__ import *
+from .core.devio.__export__ import *
+from .core.fileio.__export__ import *
+from .core.gui.__export__ import *
+from .core.thread.__export__ import *
+from .core.utils.__export__ import *
 
 _load_path=os.path.abspath(os.curdir)
 
@@ -33,4 +40,10 @@ def unload_all():
     """
     Reload all loaded modules.
     """
-    module_utils.unload_package_modules(__name__)
\ No newline at end of file
+    module_utils.unload_package_modules(__name__)
+
+def load_par(path):
+    """Load library parameters from a file"""
+    lpar=loadfile.load_dict(path)
+    for k,v in lpar.items():
+        par[k]=v
\ No newline at end of file
