@@ -1,6 +1,7 @@
 ### Interface for a generic device class ###
 
 from ..utils import functions, dictionary, general, py3, funcargparse
+from .base import DeviceError
 import functools
 import contextlib
 import collections
@@ -40,6 +41,14 @@ class IDevice:
     def __exit__(self, *args, **vargs):
         self.close()
         return False
+    @contextlib.contextmanager
+    def _close_on_error(self):
+        """Context manager, which closes the device if the code inside raises an error"""
+        try:
+            yield
+        except getattr(self,"Error",DeviceError):
+            self.close()
+            raise
     
     def _get_connection_parameters(self):
         raise NotImplementedError("IDevice._get_connection_parameters")
@@ -105,8 +114,13 @@ class IDevice:
             else:
                 return [func(ch) for ch in choices]
         return func_mux
-    def _update_device_variable_order(self, path, kind):
+    def _update_device_variable_order(self, path, kind=None):
         """Shift the order of the device variable to the current position"""
+        if kind is None:
+            for k,v in self._device_vars.items():
+                if path in v:
+                    kind=k
+                    break
         if kind not in self._device_vars:
             raise ValueError("unrecognized device variable kind: {}".format(kind))
         if path not in self._device_vars[kind]:
@@ -159,13 +173,15 @@ class IDevice:
          
         `kinds` is the list of info variables kinds to be included in the info.
         `include` specifies either a list of variables (only these variables are returned),
-        or a priority threshold (only values with the priority equal or higher are returned).
-        Since the lowest priority is -10, setting ``include=-10`` queries all available variables.
+        a priority threshold (only values with the priority equal or higher are returned), or ``"all"`` (all available variables).
+        Since the lowest priority is -10, setting ``include=-10`` queries all available variables, which is equivalent to ``include="all"``.
         """
         for kind in kinds:
             if kind not in self._device_vars:
                 raise ValueError("unrecognized device variable kind: {}".format(kind))
         info={}
+        if include=="all":
+            include=-10
         variables,priority=(None,include) if isinstance(include,int) else (include,None)
         for kind in kinds:
             for k in self._device_vars_order[kind]:
@@ -178,13 +194,27 @@ class IDevice:
                         except all_err:
                             pass
         return info
+    def _remove_device_variable(self, path, kind=None):
+        """Remove a device variable"""
+        if kind is None:
+            for k,v in self._device_vars.items():
+                if path in v:
+                    kind=k
+                    break
+        if kind not in self._device_vars:
+            raise ValueError("unrecognized device variable kind: {}".format(kind))
+        if path not in self._device_vars[kind]:
+            raise ValueError("variable {} does not exist".format(path))
+        del self._device_vars[kind][path]
+        order=self._device_vars_order[kind]
+        del order[order.index(path)]
     def get_settings(self, include=0):
         """
         Get dict ``{name: value}`` containing all the device settings.
         
         `include` specifies either a list of variables (only these variables are returned),
-        or a priority threshold (only values with the priority equal or higher are returned).
-        Since the lowest priority is -10, setting ``include=-10`` queries all available variables.
+        a priority threshold (only values with the priority equal or higher are returned), or ``"all"`` (all available variables).
+        Since the lowest priority is -10, setting ``include=-10`` queries all available variables, which is equivalent to ``include="all"``.
         """
         return self._get_device_variables(["settings"],include=include)
     def get_full_status(self, include=0):
@@ -192,8 +222,8 @@ class IDevice:
         Get dict ``{name: value}`` containing the device status (including settings).
         
         `include` specifies either a list of variables (only these variables are returned),
-        or a priority threshold (only values with the priority equal or higher are returned).
-        Since the lowest priority is -10, setting ``include=-10`` queries all available variables.
+        a priority threshold (only values with the priority equal or higher are returned), or ``"all"`` (all available variables).
+        Since the lowest priority is -10, setting ``include=-10`` queries all available variables, which is equivalent to ``include="all"``.
         """
         return self._get_device_variables(["settings","status"],include=include)
     def get_full_info(self, include=0):
@@ -201,8 +231,8 @@ class IDevice:
         Get dict ``{name: value}`` containing full device information (including status and settings).
         
         `include` specifies either a list of variables (only these variables are returned),
-        or a priority threshold (only values with the priority equal or higher are returned).
-        Since the lowest priority is -10, setting ``include=-10`` queries all available variables.
+        a priority threshold (only values with the priority equal or higher are returned), or ``"all"`` (all available variables).
+        Since the lowest priority is -10, setting ``include=-10`` queries all available variables, which is equivalent to ``include="all"``.
         """
         return self._get_device_variables(["settings","status","info"],include=include)
     def apply_settings(self, settings):
