@@ -61,7 +61,7 @@ class ParamTable(container.QWidgetContainer):
         super()._set_main_layout()
         self.main_layout.setContentsMargins(5,5,5,5)
         self.main_layout.setColumnStretch(1,1)
-    def setup(self, name=None, add_indicator=True, gui_thread_safe=False, cache_values=False, change_focused_control=False):
+    def setup(self, name=None, add_indicator=True, gui_thread_safe=False, cache_values=False, change_focused_control=False):  # pylint: disable=arguments-differ
         """
         Setup the table.
 
@@ -242,15 +242,17 @@ class ParamTable(container.QWidgetContainer):
             self.remove_layout_element(par.label)
         if par.indicator is not None:
             self.remove_layout_element(par.indicator)
-    def add_virtual_element(self, name, value=None, add_indicator=None):
+    def add_virtual_element(self, name, value=None, multivalued=False, add_indicator=None):
         """
         Add a virtual table element.
 
         Doesn't correspond to any actual widget, but behaves very similarly from the application point of view
         (its value can be set or read, it has on-change events, it can have indicator).
         The element value is simply stored on set and retrieved on get.
+        If ``multivalued==True``, the internal value is assumed to be complex, so it is forced to be a :class:`.Dictionary` every time it is set.
+        If ``add_indicator==True``, add default indicator handler as well.
         """
-        value_handler=value_handling.VirtualValueHandler(value)
+        value_handler=value_handling.VirtualValueHandler(value,multivalued=multivalued)
         if add_indicator is None:
             add_indicator=self.add_indicator
         indicator_handler=value_handling.VirtualIndicatorHandler if add_indicator else None
@@ -508,7 +510,7 @@ class ParamTable(container.QWidgetContainer):
     def get_all_values(self):
         return super().get_all_values()
     @controller.gui_thread_method
-    def set_value(self, name, value, force=False):
+    def set_value(self, name, value, force=False):  # pylint: disable=arguments-differ
         """
         Set value of a widget with the given name.
         
@@ -527,7 +529,7 @@ class ParamTable(container.QWidgetContainer):
         if allow_set:
             return super().set_value(name,value)
     @controller.gui_thread_method
-    def set_all_values(self, value, force=False):
+    def set_all_values(self, value, force=False):  # pylint: disable=arguments-differ
         """
         Set values of all widgets in the table.
         
@@ -541,6 +543,9 @@ class ParamTable(container.QWidgetContainer):
                 self.set_value(path,v,force=force)
             except KeyError:
                 pass
+    @controller.gui_thread_method
+    def update_value(self, name=None):
+        return super().update_value(name=name)
 
     def get_widget(self, name):
         name=self._normalize_name(name)
@@ -576,7 +581,7 @@ class ParamTable(container.QWidgetContainer):
     def update_indicators(self):
         return super().update_indicators()
 
-    def clear(self, disconnect=False):
+    def clear(self, disconnect=False):  # pylint: disable=arguments-differ
         """
         Clear the table (remove all widgets)
         
