@@ -703,4 +703,4 @@ class AndorSDK2Lib:
         self.SetEMCCDGain(gain)
 
 
-lib=AndorSDK2Lib()
\ No newline at end of file
+wlib=AndorSDK2Lib()
\ No newline at end of file
