@@ -1,4 +1,4 @@
 from . import PhotonFocus
-from .PhotonFocus import query_camera_name, list_cameras, get_cameras_number, PhotonFocusIMAQCamera
+from .PhotonFocus import query_camera_name, list_cameras, get_cameras_number, IPhotonFocusCamera, PhotonFocusIMAQCamera, PhotonFocusSiSoCamera, check_grabber_association
 from .PhotonFocus import PFCamError
 from .PhotonFocus import get_status_lines, get_status_line_position, remove_status_line, find_skipped_frames
\ No newline at end of file
