@@ -1,6 +1,6 @@
 from .base import ThorlabsError, ThorlabsTimeoutError
 # from .misc import PM100
 from .serial import FW, FWv1, MDT69xA
-from .kinesis import list_kinesis_devices, BasicKinesisDevice, KinesisDevice, KinesisMotor, MFF
+from .kinesis import list_kinesis_devices, BasicKinesisDevice, KinesisDevice, KinesisMotor, KinesisPiezoMotor, MFF, KinesisQuadDetector
 from .TLCamera import ThorlabsTLCamera, list_cameras as list_cameras_tlcam
 from .TLCamera import ThorlabsTLCameraError, ThorlabsTLCameraTimeoutError
\ No newline at end of file
