@@ -5,6 +5,7 @@ A small expansion on top of :class:`.pyqtgraph.PlotWidget` which allows for thre
 """
 
 import pyqtgraph
+from ....core.utils import dictionary
 
 
 class LinePlotter(pyqtgraph.PlotWidget):
@@ -88,4 +89,10 @@ class LinePlotter(pyqtgraph.PlotWidget):
                     if len(t):
                         self._traces[n][0].setData(t[:,0],t[:,1])
                     else:
-                        self._traces[n][0].setData([],[])
\ No newline at end of file
+                        self._traces[n][0].setData([],[])
+    
+    def get_all_values(self):
+        """Dummy method to satisfy child widget requirements"""
+        return dictionary.Dictionary()
+    def set_all_values(self, values):
+        """Dummy method to satisfy child widget requirements"""
\ No newline at end of file
