@@ -12,7 +12,7 @@ class AndorSDK2CameraThread(camera.GenericCameraThread):
     def connect_device(self):
         with self.using_devclass("Andor.AndorSDK2Camera",host=self.remote) as cls:
             self.device=cls(idx=self.idx)
-    def setup_task(self, idx=0, remote=None, misc=None):
+    def setup_task(self, idx=0, remote=None, misc=None):  # pylint: disable=arguments-differ
         self.idx=idx
         super().setup_task(remote=remote,misc=misc)
 
