@@ -12,7 +12,7 @@ class PicamCameraThread(camera.GenericCameraThread):
     def connect_device(self):
         with self.using_devclass("PrincetonInstruments.PicamCamera",host=self.remote) as cls:
             self.device=cls(serial_number=self.serial_number)
-    def setup_task(self, serial_number=None, remote=None, misc=None):
+    def setup_task(self, serial_number=None, remote=None, misc=None):  # pylint: disable=arguments-differ
         self.serial_number=serial_number
         super().setup_task(remote=remote,misc=misc)
     def _apply_additional_parameters(self, parameters):
